@@ -1,4 +1,4 @@
-# $Id: Directory.pm 41695 2014-06-11 08:52:21Z anton $
+# $Id: Directory.pm 42169 2014-09-08 13:09:57Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -284,6 +284,8 @@ sub verify_password {
 	my $dn = $entry->dn;
 	eval { $ldap->bind($dn, password => $password) };
 	$err = $@;
+	# fixme, verander dit in 'getFallbackPassword'
+
 	if ($err and $trySHA) {
 		my $ctx = Digest::SHA->new;
 		$ctx->add($password.$trySHA);
@@ -429,9 +431,9 @@ sub toggleAccountState {
 	my ($entry, $ldap) = $self->getEntryByUID($uid);
 
 	if ($on) {
-		my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
-		$year += 1900; $mday +=1 ;
-		my $content = sprintf("$year-%02d-%02d %02d:%02d $by", $mon, $mday, $hour,$min);
+		my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime(time);
+		$year += 1900; $mday += 1 ; $mon += 1;
+		my $content = sprintf("$year-%02d-%02d %02d:%02d $by",$mon, $mday, $hour, $min);
 		$entry->replace($attrib, $content);
 	} else {
 		$entry->delete($attrib);
